@@ -8,6 +8,7 @@ from .notes import Notes
 from .tasks import Tasks
 from .users import Users
 from .webhooks import Webhooks
+from .tags import Tags
 
 
 class Client(object):
@@ -25,6 +26,7 @@ class Client(object):
         self.tasks = Tasks(self)
         self.users = Users(self)
         self.webhooks = Webhooks(self)
+        self.tags = Tags(self)
 
     def _get(self, endpoint, **kwargs):
         return self._request('GET', endpoint, **kwargs)
